@@ -1,19 +1,19 @@
-/*     Foma: a finite-state toolkit and library.                             */
-/*     Copyright © 2008-2014 Mans Hulden                                     */
+/*   Foma: a finite-state toolkit and library.                                 */
+/*   Copyright © 2008-2015 Mans Hulden                                         */
 
-/*     This file is part of foma.                                            */
+/*   This file is part of foma.                                                */
 
-/*     Foma is free software: you can redistribute it and/or modify          */
-/*     it under the terms of the GNU General Public License version 2 as     */
-/*     published by the Free Software Foundation.                            */
+/*   Licensed under the Apache License, Version 2.0 (the "License");           */
+/*   you may not use this file except in compliance with the License.          */
+/*   You may obtain a copy of the License at                                   */
 
-/*     Foma is distributed in the hope that it will be useful,               */
-/*     but WITHOUT ANY WARRANTY; without even the implied warranty of        */
-/*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         */
-/*     GNU General Public License for more details.                          */
+/*      http://www.apache.org/licenses/LICENSE-2.0                             */
 
-/*     You should have received a copy of the GNU General Public License     */
-/*     along with foma.  If not, see <http://www.gnu.org/licenses/>.         */
+/*   Unless required by applicable law or agreed to in writing, software       */
+/*   distributed under the License is distributed on an "AS IS" BASIS,         */
+/*   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  */
+/*   See the License for the specific language governing permissions and       */
+/*   limitations under the License.                                            */
 
 #include <stdio.h>
 #include <string.h>
@@ -126,7 +126,7 @@ void escape_print(FILE *stream, char* string) {
     if (strchr(string, '"') != NULL) {
 	for (i = 0; *(string+i) != '\0'; i++) {
 	    if (*(string+i) == '"') {
-		fprintf(stream, "\\\""); 
+		fprintf(stream, "\\\"");
 	    } else {
 		fputc(*(string+i), stream);
 	    }
@@ -141,7 +141,7 @@ int foma_write_prolog (struct fsm *net, char *filename) {
   int i, *finals, *used_symbols, maxsigma;
   FILE *out;
   char *outstring, *instring, identifier[100];
-  
+
   if (filename == NULL) {
     out = stdout;
   } else {
@@ -183,14 +183,14 @@ int foma_write_prolog (struct fsm *net, char *filename) {
       instring = sigma_string(i, net->sigma);
       if (strcmp(instring,"0") == 0) {
 	  instring = "%0";
-      } 
+      }
       fprintf(out, "symbol(%s, \"", identifier);
       escape_print(out, instring);
-      fprintf(out, "\").\n"); 
+      fprintf(out, "\").\n");
 
     }
   }
-  
+
   for (; stateptr->state_no != -1; stateptr++) {
     if (stateptr->target == -1)
       continue;
@@ -209,7 +209,7 @@ int foma_write_prolog (struct fsm *net, char *filename) {
     if (strcmp(instring,"?") == 0 && stateptr->in > 2) instring = "%?";
     if (strcmp(outstring,"?") == 0 && stateptr->in > 2) outstring = "%?";
     /* Escape quotes */
-    
+
     if (net->arity == 2 && stateptr->in == IDENTITY && stateptr->out == IDENTITY) {
       fprintf(out, "\"?\").\n");
     }
@@ -218,11 +218,11 @@ int foma_write_prolog (struct fsm *net, char *filename) {
 	escape_print(out, instring);
 	fprintf(out, "\").\n");
     }
-    else if (net->arity == 2) {	
+    else if (net->arity == 2) {
       fprintf(out, "\"");
       escape_print(out, instring);
       fprintf(out, "\":\"");
-      escape_print(out, outstring); 
+      escape_print(out, outstring);
       fprintf(out, "\").\n");
     }
     else if (net->arity == 1) {
@@ -304,7 +304,7 @@ struct fsm *fsm_read_prolog (char *filename) {
     struct fsm *outnet;
     struct fsm_construct_handle *outh = NULL;
     FILE *prolog_file;
-    
+
     has_net = 0;
     prolog_file = fopen(filename, "r");
     if (prolog_file == NULL) {
@@ -324,7 +324,7 @@ struct fsm *fsm_read_prolog (char *filename) {
 	    temp_ptr2 = strstr(buf, ").");
 	    strncpy(temp, temp_ptr, (temp_ptr2 - temp_ptr));
 	    temp[(temp_ptr2-temp_ptr)] = '\0';
-	    
+
 	    /* Start network */
 	    outh = fsm_construct_init(temp);
 	}
@@ -334,7 +334,7 @@ struct fsm *fsm_read_prolog (char *filename) {
 	    temp_ptr2 = strstr(temp_ptr, ").");
 	    strncpy(temp, temp_ptr, (temp_ptr2 - temp_ptr));
 	    temp[(temp_ptr2-temp_ptr)] = '\0';
-	    
+
 	    fsm_construct_set_final(outh, atoi(temp));
 	}
 	if (strstr(buf, "symbol(") == buf) {
@@ -345,22 +345,22 @@ struct fsm *fsm_read_prolog (char *filename) {
 	    if (strcmp(temp, "%0") == 0)
 		strcpy(temp, "0");
 	    //printf("special: %s\n",temp);
-	    
+
 	    if (fsm_construct_check_symbol(outh, temp) == -1) {
 		fsm_construct_add_symbol(outh, temp);
-	    }      
+	    }
 	    continue;
 	}
 	if (strstr(buf, "arc(") == buf) {
 	    in[0] = '\0';
 	    out[0] = '\0';
-	    
+
 	    if (strstr(buf, "\":\"") == NULL || strstr(buf, ", \":\").") != NULL) {
 		arity = 1;
 	    } else {
 		arity = 2;
 	    }
-	    
+
 	    /* Get source */
 	    temp_ptr = strstr(buf, " ");
 	    temp_ptr++;
@@ -368,7 +368,7 @@ struct fsm *fsm_read_prolog (char *filename) {
 	    strncpy(temp, temp_ptr, (temp_ptr2 - temp_ptr));
 	    temp[(temp_ptr2-temp_ptr)] = '\0';
 	    source = atoi(temp);
-	    
+
 	    /* Get target */
 	    temp_ptr = strstr(temp_ptr2, " ");
 	    temp_ptr++;
@@ -376,17 +376,17 @@ struct fsm *fsm_read_prolog (char *filename) {
 	    strncpy(temp, temp_ptr, (temp_ptr2 - temp_ptr));
 	    temp[(temp_ptr2-temp_ptr)] = '\0';
 	    target = atoi(temp);
-	    
+
 	    temp_ptr = strstr(temp_ptr2, "\"");
 	    temp_ptr++;
-	    if (arity == 2)  { 
+	    if (arity == 2)  {
 		temp_ptr2 = strstr(temp_ptr, "\":");
 	    } else {
 		temp_ptr2 = strstr(temp_ptr, "\").");
 	    }
 	    strncpy(in, temp_ptr, (temp_ptr2 - temp_ptr));
 	    in[(temp_ptr2 - temp_ptr)] = '\0';
-	    
+
 	    if (arity == 2) {
 		temp_ptr = strstr(temp_ptr2, ":\"");
 		temp_ptr += 2;
@@ -421,9 +421,9 @@ struct fsm *fsm_read_prolog (char *filename) {
 	    if (strcmp(out, "%?") == 0) {
 		strcpy(out,"?");
 	    }
-	    
-	    if (arity == 1) { 
-		fsm_construct_add_arc(outh, source, target, in, in);	    
+
+	    if (arity == 1) {
+		fsm_construct_add_arc(outh, source, target, in, in);
 	    } else {
 		fsm_construct_add_arc(outh, source, target, in, out);
 	    }
@@ -463,11 +463,11 @@ char *spacedtext_get_next_line(char **text) {
     ret = *text;
     if (**text == '\0')
 	return NULL;
-    for (t = *text; *t != '\0' && *t != '\n'; t++) {	
+    for (t = *text; *t != '\0' && *t != '\n'; t++) {
     }
     if (*t == '\0')
 	*text = t;
-    else 
+    else
 	*text = t+1;
     *t = '\0';
     return(ret);
@@ -495,7 +495,7 @@ struct fsm *fsm_read_spaced_text_file(char *filename) {
     char *text, *textorig, *insym, *outsym, *t1, *t2, *l1, *l2;
 
     text = textorig = file_to_mem(filename);
-    
+
     if (text == NULL)
 	return NULL;
     th = fsm_trie_init();
@@ -690,7 +690,7 @@ static INLINE int explode_line(char *buf, int *values) {
 /* ##sigma## */
 /* ...SIGMA LINES... */
 /* ##states## */
-/* ...TRANSITION LINES... */ 
+/* ...TRANSITION LINES... */
 /* ##end## */
 
 /* Several networks may be concatenated in one file */
@@ -738,7 +738,7 @@ struct fsm *io_net_read(struct io_buf_handle *iobh, char **net_name) {
     char buf[READ_BUF_SIZE];
     struct fsm *net;
     struct fsm_state *fsm;
-    
+
     char *new_symbol;
     int i, items, new_symbol_number, laststate, lineint[5], *cm;
     int extras;
@@ -747,7 +747,7 @@ struct fsm *io_net_read(struct io_buf_handle *iobh, char **net_name) {
     if (io_gets(iobh, buf) == 0) {
         return NULL;
     }
-    
+
     net = fsm_create("");
 
     if (strcmp(buf, "##foma-net 1.0##") != 0) {
@@ -767,7 +767,7 @@ struct fsm *io_net_read(struct io_buf_handle *iobh, char **net_name) {
 #ifdef ORIGINAL
     sscanf(buf, "%i %i %i %i %i %lld %i %i %i %i %i %i %s", &net->arity, &net->arccount, &net->statecount, &net->linecount, &net->finalcount, &net->pathcount, &net->is_deterministic, &net->is_pruned, &net->is_minimized, &net->is_epsilon_free, &net->is_loop_free, &extras, buf);
 #else
-    sscanf(buf, "%i %i %i %i %i LONG_LONG_SPECIFIER %i %i %i %i %i %i %s", &net->arity, &net->arccount, &net->statecount, &net->linecount, &net->finalcount, &net->pathcount, &net->is_deterministic, &net->is_pruned, &net->is_minimized, &net->is_epsilon_free, &net->is_loop_free, &extras, buf);
+    sscanf(buf, "%i %i %i %i %i "LONG_LONG_SPECIFIER" %i %i %i %i %i %i %s", &net->arity, &net->arccount, &net->statecount, &net->linecount, &net->finalcount, &net->pathcount, &net->is_deterministic, &net->is_pruned, &net->is_minimized, &net->is_epsilon_free, &net->is_loop_free, &extras, buf);
 #endif
     strcpy(net->name, buf);
     *net_name = xxstrdup(buf);
@@ -911,15 +911,15 @@ int foma_net_print(struct fsm *net, gzFile outfile) {
     gzprintf(outfile, "%s","##props##\n");
 
     extras = (net->is_completed) | (net->arcs_sorted_in << 2) | (net->arcs_sorted_out << 4);
- 
+
 #ifdef ORIGINAL
-    gzprintf(outfile, 
+    gzprintf(outfile,
 	     "%i %i %i %i %i %lld %i %i %i %i %i %i %s\n", net->arity, net->arccount, net->statecount, net->linecount, net->finalcount, net->pathcount, net->is_deterministic, net->is_pruned, net->is_minimized, net->is_epsilon_free, net->is_loop_free, extras, net->name);
 #else
-    gzprintf(outfile, 
-	     "%i %i %i %i %i LONG_LONG_SPECIFIER %i %i %i %i %i %i %s\n", net->arity, net->arccount, net->statecount, net->linecount, net->finalcount, net->pathcount, net->is_deterministic, net->is_pruned, net->is_minimized, net->is_epsilon_free, net->is_loop_free, extras, net->name);
+    gzprintf(outfile,
+	     "%i %i %i %i %i "LONG_LONG_SPECIFIER" %i %i %i %i %i %i %s\n", net->arity, net->arccount, net->statecount, net->linecount, net->finalcount, net->pathcount, net->is_deterministic, net->is_pruned, net->is_minimized, net->is_epsilon_free, net->is_loop_free, extras, net->name);
 #endif
-    
+
     /* Sigma */
     gzprintf(outfile, "%s","##sigma##\n");
     for (sigma = net->sigma; sigma != NULL && sigma->number != -1; sigma = sigma->next) {
@@ -978,7 +978,7 @@ int net_print_att(struct fsm *net, FILE *outfile) {
     }
     for (i=0; (fsm+i)->state_no != -1; i++) {
         if ((fsm+i)->target != -1) {
-            fprintf(outfile, "%i\t%i\t%s\t%s\n",(fsm+i)->state_no,(fsm+i)->target, (sl+(fsm+i)->in)->symbol, (sl+(fsm+i)->out)->symbol);            
+            fprintf(outfile, "%i\t%i\t%s\t%s\n",(fsm+i)->state_no,(fsm+i)->target, (sl+(fsm+i)->in)->symbol, (sl+(fsm+i)->out)->symbol);
         }
     }
     prev = -1;
@@ -1003,7 +1003,8 @@ static size_t io_get_gz_file_size(char *filename) {
     /* The last four bytes in a .gz file shows the size of the uncompressed data */
     infile = fopen(filename, "r");
     fseek(infile, -4, SEEK_END);
-    fread(&bytes, 1, 4, infile);
+    if (fread(&bytes, 1, 4, infile) != 4) // value of fread was not checked in foma, this is an HFST addition
+      return -1;
     fclose(infile);
     for (i = 0 ; i < 4 ; i++) {
         ints[i] = bytes[i];
