@@ -21,16 +21,6 @@
 using std::vector;
 #include <string>
 
-/*#ifdef USE_TR1_UNORDERED_SET
-#include <tr1/unordered_set>
-using std::tr1::unordered_set;
-using std::tr1::unordered_multiset;
-#else
-#include <unordered_set>
-using std::unordered_set;
-using std::unordered_multiset;
-#endif*/
-
 #include <fst/fst.h>
 #include <fst/symbol-table.h>
 
