@@ -50,6 +50,7 @@ namespace fst
 }
 #endif
 
+#include <stdint.h>
 #ifdef _MSC_VER
 typedef __int64 int64;
 #else
@@ -89,6 +90,7 @@ namespace implementations
   public:
     LogWeightInputStream(void);
     LogWeightInputStream(const std::string &filename);
+    LogWeightInputStream(std::istream &is);
     void close(void);
     bool is_eof(void) const;
     bool is_bad(void) const;
@@ -184,6 +186,7 @@ namespace implementations
       static LogFst * set_weight(LogFst * t,float f);
       static LogFst * set_final_weights(LogFst * t, float weight);
       static LogFst * transform_weights(LogFst * t,float (*func)(float f));
+      static LogFst * push_labels(LogFst * t, bool to_initial_state);
       static LogFst * push_weights(LogFst * t, bool to_initial_state);
 
       static std::pair<LogFst*, LogFst*> harmonize
