@@ -51,6 +51,7 @@ namespace fst
 }
 #endif
 
+#include <stdint.h>
 #ifdef _MSC_VER
 typedef __int64 int64;
 #else
@@ -89,6 +90,7 @@ namespace implementations
   public:
     TropicalWeightInputStream(void);
     TropicalWeightInputStream(const std::string &filename);
+    TropicalWeightInputStream(std::istream &is);
     void close(void);
     bool is_eof(void) const;
     bool is_bad(void) const;
@@ -202,6 +204,9 @@ namespace implementations
         (StdVectorFst * t,float (*func)(float f));
       static StdVectorFst * push_weights
         (StdVectorFst * t, bool to_initial_state);
+      static StdVectorFst * push_labels
+        (StdVectorFst * t, bool to_initial_state);
+
       static bool has_weights(const StdVectorFst * t);
 
       static std::pair<StdVectorFst*, StdVectorFst*> harmonize
@@ -264,6 +269,9 @@ namespace implementations
       static void get_first_input_symbols
         (StdVectorFst *t, StateId s, std::set<StateId> & visited_states, StringSet & symbols);
       static StringSet get_first_input_symbols(StdVectorFst *t);
+      static void get_initial_input_symbols
+        (StdVectorFst *t, StateId s, std::set<StateId> & visited_states, StringSet & symbols);
+      static StringSet get_initial_input_symbols(StdVectorFst *t);
       static unsigned int get_symbol_number(StdVectorFst *t,
                         const std::string &symbol);
       static unsigned int get_biggest_symbol_number(StdVectorFst *t);
