@@ -9,6 +9,14 @@
 
 #include "pmatch_tokenize.h"
 
+
+#if USE_ICU_UNICODE
+#include <unicode/unistr.h>
+#include <unicode/brkiter.h>
+static UErrorCode characterBoundaryStatus = U_ZERO_ERROR;
+static icu::BreakIterator* characterBoundary = icu::BreakIterator::createCharacterInstance(NULL, characterBoundaryStatus);
+#endif
+
 namespace hfst_ol_tokenize {
 
 using std::string;
@@ -22,6 +30,16 @@ using hfst_ol::LocationVectorVector;
 static const string subreading_separator = "#";
 static const string wtag = "W"; // TODO: cg-conv has an argument --wtag, allow changing here as well?
 
+void print_escaping_backslashes(std::string const & str, std::ostream & outstream)
+{
+    // TODO: inline?
+    size_t i = 0, j = 0;
+    while((j = str.find("\\", i)) != std::string::npos) {
+        outstream << str.substr(i, j-i) << "\\\\";
+        i = j+1;
+    }
+    outstream << str.substr(i, j-i);
+}
 
 void print_no_output(std::string const & input, std::ostream & outstream, const TokenizeSettings& s)
 {
@@ -30,7 +48,11 @@ void print_no_output(std::string const & input, std::ostream & outstream, const
     } else if (s.output_format == xerox) {
         outstream << input << "\t" << input << "+?";
     } else if (s.output_format == cg || s.output_format == giellacg) {
-	    outstream << "\"<" << input << ">\"" << std::endl << "\t\"" << input << "\" ?";
+	    outstream << "\"<";
+        print_escaping_backslashes(input, outstream);
+        outstream << ">\"" << std::endl << "\t\"";
+        print_escaping_backslashes(input, outstream);
+        outstream << "\" ?";
     }
 //    std::cerr << "from print_no_output\n";
     outstream << "\n\n";
@@ -54,7 +76,11 @@ void print_nonmatching_sequence(std::string const & str, std::ostream & outstrea
     } else if (s.output_format == xerox) {
         outstream << str << "\t" << str << "+?";
     } else if (s.output_format == cg) {
-        outstream << "\"<" << str << ">\"" << std::endl << "\t\"" << str << "\" ?";
+        outstream << "\"<";
+        print_escaping_backslashes(str, outstream);
+        outstream << ">\"" << std::endl << "\t\"";
+        print_escaping_backslashes(str, outstream);
+        outstream << "\" ?";
     } else if (s.output_format == giellacg) {
         outstream << ":";
         print_escaping_newlines(str, outstream);
@@ -202,10 +228,20 @@ size_t u8_first_codepoint_size(const unsigned char* c) {
  * Since non-Multichar_symbols may still be multi*byte*, we check that
  * the symbol is strictly longer than the size of the first
  * possibly-multi-byte codepoint.
+ *
+ * If we have ICU, we check that the symbol is longer than the first
+ * "character" (so characters composed of multiple codepoints are
+ * treated the same as their non-composed counterparts).
  */
 bool is_cg_tag(const string & str) {
+#if USE_ICU_UNICODE
+    icu::UnicodeString us(str.c_str());
+    characterBoundary->setText(us);
+    return us.length() > characterBoundary->following(0);
+#else
     // Note: invalid codepoints are also treated as tags;  ¯\_(ツ)_/¯
     return str.size() > u8_first_codepoint_size((const unsigned char*)str.c_str());
+#endif
 }
 
 void print_cg_subreading(size_t const & indent,
@@ -237,7 +273,7 @@ void print_cg_subreading(size_t const & indent,
                 outstream << "\"";
             }
         }
-        outstream << (*it);
+        print_escaping_backslashes(*it, outstream);
     }
     if(in_lemma) {
         outstream << "\"";
@@ -270,7 +306,9 @@ void print_cg_subreading(size_t const & indent,
     if (in_beg != in_end) {
         std::ostringstream form;
         std::copy(in_beg, in_end, std::ostream_iterator<string>(form, ""));
-        outstream << " \"<" << form.str() << ">\"";
+        outstream << " \"<";
+        print_escaping_backslashes(form.str(), outstream);
+        outstream << ">\"";
     }
     outstream << std::endl;
 }
@@ -426,10 +464,14 @@ void print_location_vector_giellacg(hfst_ol::PmatchContainer & container,
                                     std::ostream & outstream,
                                     const TokenizeSettings& s)
 {
-    outstream << "\"<" << locations.at(0).input << ">\"" << std::endl;
+    outstream << "\"<";
+    print_escaping_backslashes(locations.at(0).input, outstream);
+    outstream << ">\"" << std::endl;
     if(locations.size() == 1 && locations.at(0).output.empty()) {
         // Treat empty analyses as unknown-but-tokenised:
-        outstream << "\t\"" << locations.at(0).input << "\" ?" << std::endl;
+        outstream << "\t\"";
+        print_escaping_backslashes(locations.at(0).input, outstream);
+        outstream << "\" ?" << std::endl;
         return;
     }
     // Output regular analyses first, making a note of backtracking points.
@@ -619,7 +661,9 @@ void print_location_vector(hfst_ol::PmatchContainer & container,
         }
     } else if (s.output_format == cg && locations.size() != 0) {
         // Print the cg cohort header
-        outstream << "\"<" << locations.at(0).input << ">\"" << std::endl;
+        outstream << "\"<";
+        print_escaping_backslashes(locations.at(0).input, outstream);
+        outstream << ">\"" << std::endl;
         for (LocationVector::const_iterator loc_it = locations.begin();
              loc_it != locations.end(); ++loc_it) {
             // For the most common case, eg. analysis strings that begin with the original input,
@@ -627,7 +671,9 @@ void print_location_vector(hfst_ol::PmatchContainer & container,
             // Otherwise we omit the double quotes and assume the rule writer knows what he's doing.
             if (loc_it->output.find(loc_it->input) == 0) {
                 // The nice case obtains
-                outstream << "\t\"" << loc_it->input << "\"" <<
+                outstream << "\t\"";
+                print_escaping_backslashes(loc_it->input, outstream);
+                outstream << "\"" <<
                     loc_it->output.substr(loc_it->input.size(), std::string::npos);
             } else {
                 outstream << "\t" << loc_it->output;
