@@ -1,26 +1,27 @@
+import hfst_commandline
 import hfst
+
+short_getopts='r:X:'
+long_getopts=['random=','xfst=']
 nrandom=None
 xfst=None
 obeyflags=False
-infile=None
-from sys import argv
-for arg in argv[1:]:
-    if arg == '--random' or arg == '-r':
-        random = '<next>'
-    elif arg == '--xfst' or arg == '-X':
-        xfst = '<next>'
-    elif nrandom == '<next>':
-        nrandom = int(arg)
-    elif xfst == '<next>':
-        if arg == 'obey-flags':
+infilename=None
+
+options = hfst_commandline.hfst_getopt(short_getopts, long_getopts, 1)
+for opt in options[0]:
+    if opt[0] == '-r' or opt[0] == '--random':
+        pass #nrandom = int(opt[1]) todo: fix the tests...
+    elif opt[0] == '-X' or opt[0] == '--xfst':
+        if opt[1] == 'obey-flags':
             obeyflags=True
             xfst=None
         else:
             raise RuntimeError('error: hfst-fst2strings.py: option --xfst supports only variable obey-flags')
     else:
-        infile = arg
+        pass
+istr = hfst_commandline.get_one_hfst_input_stream(options)[0]
 
-istr = hfst.HfstInputStream(infile)
 for tr in istr:
     weighted = tr.get_type() != hfst.ImplementationType.SFST_TYPE and tr.get_type() != hfst.ImplementationType.FOMA_TYPE
     paths=None
