@@ -105,7 +105,7 @@ parse_options(int argc, char** argv)
           {0,0,0,0}
         };
         int option_index = 0;
-        char c = getopt_long(argc, argv, HFST_GETOPT_COMMON_SHORT
+        int c = getopt_long(argc, argv, HFST_GETOPT_COMMON_SHORT
                              HFST_GETOPT_BINARY_SHORT "FHx:X:",
                              long_options, &option_index);
         if (-1 == c)
@@ -228,7 +228,7 @@ compose_streams(HfstInputStream& firststream, HfstInputStream& secondstream)
         char* secondname = hfst_get_name(*second, secondfilename);
         if (transducer_n_first == 1)
         {
-            verbose_printf("Composing %s and %s...\n", firstname, 
+            verbose_printf("Composing %s and %s...\n", firstname,
                            secondname);
         }
         else
@@ -237,20 +237,20 @@ compose_streams(HfstInputStream& firststream, HfstInputStream& secondstream)
                            firstname, secondname, transducer_n_first);
         }
 
-        if (first->has_flag_diacritics() or second->has_flag_diacritics()) 
+        if (first->has_flag_diacritics() or second->has_flag_diacritics())
           {
             if (not harmonize_flags)
               {
-                if (not silent) 
+                if (not silent)
                   {
                     warning(0, 0, "At least one of the arguments contains "
-                            "flag diacritics. Use -F to harmonize them.", 
+                            "flag diacritics. Use -F to harmonize them.",
                             secondname, firstname);
                   }
               }
             else
               {
-                try 
+                try
                   {
                     first->harmonize_flag_diacritics(*second);
                   }
@@ -299,7 +299,7 @@ compose_streams(HfstInputStream& firststream, HfstInputStream& secondstream)
 
         outstream << *first;
 
-        continueReading = 
+        continueReading =
           (firststream.is_good() && secondstream.is_good())  ||
           (firststream.is_good() && (transducer_n_second == 1))  ||
           ((transducer_n_first == 1) && secondstream.is_good());
@@ -321,13 +321,13 @@ compose_streams(HfstInputStream& firststream, HfstInputStream& secondstream)
               }
           }
 
-        //continueReading = firststream.is_good() && 
+        //continueReading = firststream.is_good() &&
         //  (secondstream.is_good() || transducer_n_second == 1);
 
         //delete first;
         //first=0;
         // delete the transducer of second stream, unless we continue reading
-        // the first stream and there is only one transducer in the second 
+        // the first stream and there is only one transducer in the second
         // stream
         //if ((continueReading && secondstream.is_good()) || not continueReading)
         //  {
@@ -341,19 +341,19 @@ compose_streams(HfstInputStream& firststream, HfstInputStream& secondstream)
     
     if (firststream.is_good())
       {
-        error(EXIT_FAILURE, 0, 
+        error(EXIT_FAILURE, 0,
               "second input '%s' contains fewer transducers than first input"
               " '%s'; this is only possible if the second input contains"
-              " exactly one transducer", 
+              " exactly one transducer",
               secondfilename, firstfilename);
       }
 
     if (secondstream.is_good())
       {
-        error(EXIT_FAILURE, 0, 
+        error(EXIT_FAILURE, 0,
               "first input '%s' contains fewer transducers than second input"
               " '%s'; this is only possible if the first input contains"
-              " exactly one transducer", 
+              " exactly one transducer",
               firstfilename, secondfilename);
       }
 
@@ -390,7 +390,7 @@ int main( int argc, char **argv ) {
     {
         fclose(outfile);
     }
-    verbose_printf("Reading from %s and %s, writing to %s\n", 
+    verbose_printf("Reading from %s and %s, writing to %s\n",
         firstfilename, secondfilename, outfilename);
     // here starts the buffer handling part
     HfstInputStream* firststream = NULL;
@@ -413,7 +413,7 @@ int main( int argc, char **argv ) {
         new HfstOutputStream(outfilename, firststream->get_type()) :
         new HfstOutputStream(firststream->get_type());
 
-    if ( is_input_stream_in_ol_format(firststream, "hfst-compose") || 
+    if ( is_input_stream_in_ol_format(firststream, "hfst-compose") ||
          is_input_stream_in_ol_format(secondstream, "hfst-compose") )
       {
         return EXIT_FAILURE;
