@@ -98,15 +98,15 @@ print_usage()
 "  -S, --print-separator      print separator \"--\" after each transducer\n"
 "  -e, --epsilon-format=EPS   print epsilon as EPS\n"
 "  -X, --xfst=VARIABLE        toggle xfst compatibility option VARIABLE\n");
-    fprintf(message_out, "Ignore paths if:\n"
-"  -b, --beam=B               output string weight not within B from the weight\n"
-"                             of the best output string\n"
-"  -l, --max-in-length=MIL    input string longer than MIL\n"
-"  -L, --max-out-length=MOL   output string longer than MOL\n"
-"  -p, --in-prefix=OPREFIX    input string not beginning with IPREFIX\n"
-"  -P, --out-prefix=OPREFIX   output string not beginning with OPREFIX\n"
-"  -u, --in-exclude=IXSTR     input string containing IXSTR\n"
-"  -U, --out-exclude=OXST     output string containing OXSTR\n");
+    fprintf(message_out, "Path filters:\n"
+"  -b, --beam=B               reject output string with weight more than B away from\n"
+"                             the weight of the best output string\n"
+"  -l, --max-in-length=MIL    reject input string longer than MIL\n"
+"  -L, --max-out-length=MOL   reject output string longer than MOL\n"
+"  -p, --in-prefix=OPREFIX    input string must begin with IPREFIX\n"
+"  -P, --out-prefix=OPREFIX   output string must begin with OPREFIX\n"
+"  -u, --in-exclude=IXSTR     input string must not contain IXSTR\n"
+"  -U, --out-exclude=OXST     output string must not contain OXSTR\n");
 
     fprintf(message_out, "\n");
 
@@ -124,8 +124,10 @@ print_usage()
     fprintf(message_out,
         "\n"
         "Examples:\n"
-        "  %s lexical.hfst  generates all forms of lexical.hfst\n"
-        "\n", program_name);
+        "  %s lexical.hfst    generates all forms of lexical.hfst\n"
+        "  %s -P \"cat<n>\" -c 0 lexical.hfst\n"
+        "                     generates paradigm for cat<n> without following cycles\n"
+        "\n", program_name, program_name);
 
     fprintf(message_out,
         "Known bugs:\n"
@@ -386,7 +388,7 @@ public:
             {
               *out_ << " ";
             }
-        
+
           *out_ << get_print_format(it->first);
           first_pair=false;
         }
@@ -422,7 +424,7 @@ public:
               }
             if (it->first.compare(it->second) != 0)
               is_automaton=false;
-            
+
             *out_ << get_print_format(it->first);
           }
         first_symbol=false;
@@ -466,14 +468,14 @@ int
 process_stream(HfstInputStream& instream, std::ostream& outstream)
 {
   //instream.open();
-  
+
   bool first_transducer=true;
   while(instream.is_good())
   {
     if (!first_transducer && print_separator_after_each_transducer)
       outstream << "--" << std::endl;
     first_transducer=false;
-    
+
     HfstTransducer t(instream);
 
     /* Pairstring format is not supported on optimized lookup format. */
@@ -485,10 +487,10 @@ process_stream(HfstInputStream& instream, std::ostream& outstream)
           "       optimized lookup transducers, exiting program\n" );
       exit(1);
     }
- 
+
     if(input_prefix != "")
       verbose_printf("input_prefix: '%s'\n", input_prefix.c_str());
-    
+
     if(beam >= 0)
       {
         verbose_printf("Finding the weight of the best path...\n");
@@ -563,7 +565,7 @@ process_stream(HfstInputStream& instream, std::ostream& outstream)
         return EXIT_FAILURE;
       }
     }
-    
+
     if(max_strings > 0)
       verbose_printf("Finding at most %i path(s)...\n", max_strings);
     else if(max_random_strings > 0)
@@ -571,7 +573,7 @@ process_stream(HfstInputStream& instream, std::ostream& outstream)
              max_random_strings);
     else
       verbose_printf("Finding strings...\n");
-    
+
     /* not random strings */
     if (max_random_strings <= 0)
       {
@@ -606,7 +608,7 @@ process_stream(HfstInputStream& instream, std::ostream& outstream)
         }
       return EXIT_FAILURE;
     }
-      
+
     Callback cb(max_random_strings, &outstream);
     for (HfstTwoLevelPaths::const_iterator it = results.begin();
          it != results.end(); it++)
@@ -620,7 +622,7 @@ process_stream(HfstInputStream& instream, std::ostream& outstream)
     //if (print_separator_after_each_transducer)
     //  outstream << "--" << std::endl;
   }
-    
+
   instream.close();
   return EXIT_SUCCESS;
 }
@@ -666,7 +668,7 @@ int main( int argc, char **argv ) {
         fprintf(stderr, "%s is not a valid transducer file\n", inputfilename);
         return EXIT_FAILURE;
     }
-    
+
     if (outfile != stdout)
     {
       std::ofstream outstream(outfilename);
@@ -674,7 +676,7 @@ int main( int argc, char **argv ) {
     }
     else
       retval = process_stream(*instream, std::cout);
-    
+
     delete instream;
     free(inputfilename);
     free(outfilename);
