@@ -93,12 +93,12 @@ parse_options(int argc, char** argv)
           HFST_GETOPT_COMMON_LONG,
           HFST_GETOPT_UNARY_LONG,
           {"n-first", required_argument, 0, 'n'},
-          // add tool-specific options here 
+          // add tool-specific options here
             {0,0,0,0}
         };
         int option_index = 0;
-        // add tool-specific options here 
-        char c = getopt_long(argc, argv, HFST_GETOPT_COMMON_SHORT
+        // add tool-specific options here
+        int c = getopt_long(argc, argv, HFST_GETOPT_COMMON_SHORT
                              HFST_GETOPT_UNARY_SHORT "n:",
                              long_options, &option_index);
         if (-1 == c)
@@ -141,7 +141,7 @@ process_stream(HfstInputStream& instream, HfstOutputStream& outstream)
               {
                 inputname = strdup(inputfilename);
               }
-            verbose_printf("Forwarding %s..." SIZE_T_SPECIFIER "\n", inputname, transducer_n); 
+            verbose_printf("Forwarding %s..." SIZE_T_SPECIFIER "\n", inputname, transducer_n);
             outstream << trans;
           }
       }
@@ -176,7 +176,7 @@ process_stream(HfstInputStream& instream, HfstOutputStream& outstream)
               {
                 inputname = strdup(inputfilename);
               }
-            verbose_printf("Forwarding %s..." SIZE_T_SPECIFIER "\n", inputname, transducer_n); 
+            verbose_printf("Forwarding %s..." SIZE_T_SPECIFIER "\n", inputname, transducer_n);
             outstream << trans;
             first_but_n.pop_front();
           }
@@ -209,7 +209,7 @@ int main( int argc, char **argv ) {
     {
         fclose(outfile);
     }
-    verbose_printf("Reading from %s, writing to %s\n", 
+    verbose_printf("Reading from %s, writing to %s\n",
         inputfilename, outfilename);
     // here starts the buffer handling part
     HfstInputStream* instream = NULL;
