@@ -200,9 +200,9 @@ ApertiumOutputFormatter::process_finals(const LookupPathSet& finals, Capitalizat
   {
     std::ostringstream res;
     res << token_stream.get_alphabet().symbols_to_string((*it)->get_output_symbols(), caps);
-    if(dynamic_cast<const LookupPathW*>(*it) != NULL && displayWeightsFlag)
-      res << '~' << dynamic_cast<const LookupPathW*>(*it)->get_weight() << '~';
-
+    if (dynamic_cast<const LookupPathW *>(*it) != NULL && displayWeightsFlag) {
+      res << '~' << dynamic_cast<const LookupPathW *>(*it)->get_weight() << '~';
+    }
     results.push_back(res.str());
   }
   return results;
@@ -288,8 +288,9 @@ CGOutputFormatter::process_final(const SymbolNumberVector& symbols, Capitalizati
     }
 
     // grab the base form without tags
+    size_t end = (compound_split < tag_start ? compound_split : tag_start);
     res << token_stream.get_alphabet().symbols_to_string(
-      SymbolNumberVector(symbols.begin()+start_pos,symbols.begin()+tag_start), caps);
+      SymbolNumberVector(symbols.begin()+start_pos,symbols.begin()+end), caps);
 
     // look for compounding. Don't output the tags for non-final segments
     if(compound_split != symbols.size())
